/*******************************************************************************
*
*	TITLE:		beacon.h 
*
*	VERSION:	1.0                           
*
*	DATE:		09-Jan-2004
*
*	AUTHOR:		R. Kevin Watson
*
*	COMMENTS:
*
********************************************************************************
*
*	Change log:
*
*	DATE         REV  DESCRIPTION
*	-----------  ---  ----------------------------------------------------------
*	28-Nov-2003  0.1  RKW Original
*	09-Jan-2004  1.0  RKW - This version used for kick-off demo
*
*******************************************************************************/

// function prototypes
void Initialize_Beacon(void);
void Timer_0_Int_Handler(void);

// some handy macros
#define HIBYTE(value) ((unsigned char)(((unsigned int)(value)>>8)&0xFF))
#define LOBYTE(value) ((unsigned char)(value))

// beacon state variable defines
#define BEACON_0_ON 0
#define BETWEEN_BEACON_0_AND_1 1
#define BEACON_1_ON 2
#define BETWEEN_BEACON_1_AND_0 3

// CCP module defines
#define PWM_OFF 0x00
#define PWM_ON 0x0C

// This sets the total (high+low time) PWM period.
// For a 40MHz clock, this should be 250 for a 40KHz 
// PWM frequency. Set to 10000000/desired_frequency. 
#define PWM_TOTAL_PERIOD 250

// This sets the PWM high period, which should be 
// half of PWM_TOTAL_PERIOD for a 50% duty cycle.
// Set to 10000000*desired_high_period.
#define PWM_HIGH_PERIOD 125

// This sets the period of time that the beacon 0
// IR LEDs are allowed to flash at the PWM frequency 
// before being turned off. 
// Set to 65536-(period/0.0000008)
#define BEACON_0_ON_PERIOD 64286 // 40 pulses = 0.00100s

// This sets the period of time that the beacon 1
// IR LEDs are allowed to flash at the PWM frequency 
// before being turned off. 
// Set to 65536-(period/0.0000008)
#define BEACON_1_ON_PERIOD 63036 // 80 pulses = 0.00200s

// This sets the period of time that the IR LEDs are
// turned off between beacon bursts. For a 50Hz beacon
// flash rate, beacon off period should be: 
// (0.02 - (beacon 0 on period + beacon 1 on period))/2
// Set to 65536-(period/0.0000008) 
//#define BEACON_OFF_PERIOD 54911 // 0.00850s for 50Hz
#define BEACON_OFF_PERIOD 61161 // 0.00350s for 100Hz
// #define BEACON_OFF_PERIOD 64286 // 0.00100s for 200Hz

